@@ -1,7 +1,7 @@
 /*
  * queue.c: Functions that handle the queue handlers
  * rspfd: Radio Shortest Path Daemon. A router for packet radio networks.
- * Copyright (C) 1995 Craig Small VK2XLZ
+ * Copyright (C) 1995-2001 Craig Small VK2XLZ
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,10 +17,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-#include "queue.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <syslog.h> 
+#include <string.h>
+#include "queue.h"
 /*
  * create_queue()
  *
