@@ -1,6 +1,10 @@
 /*
  * Takes udp requests and processes them
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <ctype.h>
 #include <netdb.h>
 #include <stdio.h>
@@ -10,12 +14,22 @@
 #include <signal.h>
 #include <netinet/in.h> 
 #include <sys/socket.h> 
-#include <sys/time.h>
 #include <sys/types.h> 
 #include <arpa/inet.h> 
-#include <linux/ax25.h> 
+#include <netax25/ax25.h> 
 #include <net/if.h>
 
+#ifdef TIME_WITH_SYS_TIME
+#include <sys/time.h>
+#include <time.h>
+#else
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
+#else
+#include <time.h>
+#endif
+#endif
+
 #include "rspfax25.h"
 #include "rspftcp.h"
 #include "queue.h"
@@ -54,36 +68,39 @@ char* in_ntoa(u_long addr);
 
 int init_tcp(int port)
 {
-	struct sockaddr_in asin;
-	struct protoent *ppe;
-	int s;
-	
-	bzero((char*)&asin, sizeof(asin));
-	asin.sin_family = AF_INET;
-	asin.sin_addr.s_addr = INADDR_ANY;
-	asin.sin_port = htons(port);
-	
-	if ( (ppe = getprotobyname("tcp")) == 0)
-	{
-		syslog(LOG_DAEMON | LOG_ERR, "init_tcp(): getprotobyname failed (%m)");
-		return -1;
-	}
-	
-	if ( (s= socket(PF_INET, SOCK_STREAM, ppe->p_proto)) < 0)
-	{
-		syslog(LOG_DAEMON | LOG_ERR, "init_tcp(): socket failed (%m)");
-		(void)close(s);
-		return -1;
-	}
-	
-	if (bind(s, (struct sockaddr *)&asin, sizeof(asin)) < 0)
-	{
-		syslog(LOG_DAEMON | LOG_ERR, "init_tcp(): bind failed (%m)");
-		return -1;
-	}
-	listen(s, 3);	
-	
-	return s;
+  struct addrinfo hints;
+  struct addrinfo *res;
+  int error;
+  char service[16];
+  int skt;
+
+  memset(&hints, 0, sizeof(hints));
+  hints.ai_family = PF_UNSPEC;
+  hints.ai_flags = AI_PASSIVE;
+  hints.ai_socktype = SOCK_STREAM;
+  sprintf(service, "%d", port);
+  if ( (error = getaddrinfo(NULL, service, &hints, &res))) {
+    syslog(LOG_DAEMON | LOG_ERR, "init_tcp(): getaddrinfo failed: %s", gai_strerror(error));
+    return -1;
+  }
+  while (res) {
+    skt = -1;
+    if ( (skt = socket(res->ai_family,  res->ai_socktype, res->ai_protocol)) < 0) {
+      syslog(LOG_DAEMON | LOG_ERR, "init_tcp(): socket failed (%m)");
+      continue;
+    }
+    if (bind(skt, res->ai_addr, res->ai_addrlen) < 0) {
+      syslog(LOG_DAEMON | LOG_ERR, "init_tcp(): bind failed (%m)");
+      continue;
+    }
+    if (listen(skt, 5) != 0) {
+      syslog(LOG_DAEMON | LOG_ERR, "init_tcp(): listen failed (%m)");
+      continue;
+    }
+    return skt;
+  } /* while */
+  syslog(LOG_DAEMON | LOG_ERR, "init_tcp(): no sockets found");
+  return -1;
 
 }
 
@@ -105,7 +122,6 @@ static const struct tcp_commands commands[] = {
 	{ "quit",	send_quit },
 	{ "router",	send_routers },
 	{ "route",	send_routes },
-
 	{ "stat",	send_stats },
 	{ 0,		0	}
 };
